import React, { useState, useEffect, useRef } from "react";
import { connect } from "react-redux";
import { book } from "../../redux/actions";
import _ from "lodash";
import dropdown from "../../assets/icons/dropdown.png";

function GradeFilter({
  selectedGrade,
  gradeFilter,
  grades,
  gradeDropdown,
  setGradeDropdown,
  theme,
}: any) {
  const [arrowTop, setArrowTop] = useState(false);

  useEffect(() => {
    setGradeDropdown(false);
  }, [selectedGrade]);

  const mobileList = useRef<HTMLUListElement>(null);

  const setDropdown = (e: any) => {
    e.stopPropagation();
    setGradeDropdown(!gradeDropdown);
  };

  return (
    <section
      className={_.join(
        [
          "grade-filter d-flex align-items-center",
          theme === "light" ? "grade-filter-light" : "grade-filter-dark",
        ],
        " "
      )}
      style={{
        transform:
          window.innerWidth > 1027
            ? `translateY(-${window.innerHeight / 2}px)`
            : "",
      }}
    >
      <h1 className="d-flex align-items-center">
        پایه تحصیلی
        <span className="desktop"></span>
      </h1>
      <div
        className="grade-filter__box mobile"
        onClick={(e: any) => setDropdown(e)}
      >
        {selectedGrade ? (
          <h2>{grades[selectedGrade - 1].name}</h2>
        ) : (
          <span>پایه تحصیلی خود را انتخاب نمائید</span>
        )}
        <img
          src={dropdown}
          style={{ transform: !arrowTop ? "rotate(180deg)" : "rotate(0deg)" }}
          alt=""
        />
      </div>
      {gradeDropdown ? (
        <ul className="grade-filter__list d-flex flex-wrap">
          {grades.map((item: any, i: any) => (
            <li
              key={i}
              onClick={() => gradeFilter(item.value)}
              className={
                selectedGrade === item.value ? "grade-filter__list--active" : ""
              }
            >
              {item.name}
            </li>
          ))}
        </ul>
      ) : null}

      <ul className="desktop align-items-center" ref={mobileList}>
        {selectedGrade && (
          <figure
            style={{
              right:
                ((mobileList as any).current?.offsetWidth / 11) *
                (selectedGrade - 1),
            }}
          ></figure>
        )}
        {grades.map((item: any, i: any) => (
          <li
            key={i}
            onClick={(e) => gradeFilter(item.value)}
            className={
              selectedGrade === item.value ? "grade-filter__active" : ""
            }
          >
            {item.name}
          </li>
        ))}
      </ul>
    </section>
  );
}

export default connect(
  (state: any) => ({
    selectedGrade: state.book.selectedGrade,
    theme: state.publicApi.theme,
  }),
  { gradeFilter: book.gradeFilter }
)(GradeFilter);
