import React, { useState } from "react";
import MenuRoundedIcon from "@mui/icons-material/MenuRounded";
import { Link } from "react-router-dom";
import { SwipeableDrawer } from "@mui/material";
import NavbarDrawer from "../NavbarDrawer/NavbarDrawer";
import clsx from "clsx";
import proxy from "../../redux/proxy";
import { makeStyles } from "@mui/styles";
import Menu from "../Menu/index";
import logoIcon from "../../assets/icons/logo.png";
import { connect } from "react-redux";
import _ from "lodash";
import searchIcon from "../../assets/icons/search.png";
import searchBlackIcon from "../../assets/icons/searchBlack.svg";
import ThemeSwitch from "../ThemeSwitch";

const useStyles = makeStyles({
  list: {
    width: window.innerWidth * 0.8,
  },
  fullList: {
    width: "auto",
    direction: "rtl",
    textAlign: "right",
  },
});

function Navbar(props: any) {
  const status = proxy.status();
  const classes = useStyles();
  const [state, setState] = useState({
    top: false,
    left: false,
    bottom: false,
    right: false,
    searchFlag: false,
  });
  const { page, theme } = props;

  const toggleDrawer = (anchor: any, open: any) => (event: any) => {
    console.log("on");
    if (
      event &&
      event.type === "keydown" &&
      (event.key === "Tab" || event.key === "Shift")
    ) {
      return;
    }

    setState({ ...state, [anchor]: open });
  };

  const list = (props: any, anchor: any) => (
    <div
      className={clsx(classes.list, {
        [classes.fullList]: anchor === "top" || anchor === "bottom",
      })}
      role="presentation"
    >
      <NavbarDrawer
        setShare={props.setShare}
        user={props.user}
        logout={props.logout}
        needUpdate={props.needUpdate}
        theme={theme}
      />
    </div>
  );

  const userStatus = proxy.status();
  return (
    <nav
      className={_.join(
        [
          "nav align-items-center justify-content-center",
          theme === "light" ? "bg-white nav-light" : "nav-dark bg-dark",
        ],
        " "
      )}
      style={{
        backgroundColor:
          theme === "light" ? "rgba(255,255,255, 0.5)" : "rgba(0,0,0, 0.85)",
      }}
    >
      <div className="nav__container d-flex align-items-center justify-content-between">
        <ul className="nav__container--links desktop align-items-center">
          <li className="nav___logo d-flex align-items-center">
            <Link to="/">
              <img src={logoIcon} alt="" />
            </Link>
            <span></span>
          </li>
          <li>
            <Menu items={props.grades} />
          </li>
        </ul>
        <MenuRoundedIcon
          className="mobile"
          style={{ color: theme === "dark" ? "white" : "#555", fontSize: 40 }}
          onClick={toggleDrawer("right", true)}
        />
        <ul className="nav__container--buttons d-flex align-items-center">
          <li><ThemeSwitch /></li>
          <li className="nav__search">
            <Link to="/search">
              {theme === "dark" ? (
                <img src={searchIcon} alt="" />
              ) : (
                <img src={searchBlackIcon} alt="" />
              )}
            </Link>
          </li>
          <li className="nav___share desktop">
            <Link to="/subscribe">خرید اشتراک</Link>
          </li>
          {!userStatus && (
            <li className="nav___login d-flex">
              <Link to="/login">ورود</Link>
            </li>
          )}
        </ul>
      </div>
      <SwipeableDrawer
        anchor="right"
        open={state["right"]}
        onClose={toggleDrawer("right", false)}
        onOpen={toggleDrawer("right", true)}
      >
        {list(props, "right")}
      </SwipeableDrawer>
    </nav>
  );
}

export default connect((state: any) => ({
  theme: state.publicApi.theme,
}))(Navbar);

Navbar.defaultProps = {
  grades: [
    {
      name: "اول",
      value: 1,
    },
    {
      name: "دوم",
      value: 2,
    },
    {
      name: "سوم",
      value: 3,
    },
    {
      name: "چهارم",
      value: 4,
    },
    {
      name: "پنجم",
      value: 5,
    },
    {
      name: "ششم",
      value: 6,
    },
    {
      name: "هفتم",
      value: 7,
    },
    {
      name: "هشتم",
      value: 8,
    },
    {
      name: "نهم",
      value: 9,
    },
    {
      name: "دهم",
      value: 10,
    },
    {
      name: "یازدهم",
      value: 11,
    },
    {
      name: "دوازدهم",
      value: 12,
    },
  ],
};
