import React, { useState, useRef, useEffect } from "react";
import Navbar from "../../../components/Navbar";
import Footer from "../../Home/Footer";
import Input from "../../../components/Input";
import CustomCheckbox from "../../../components/CustomCheckbox/index";
import CheckBoxOutlineBlankTwoToneIcon from "@mui/icons-material/CheckBoxOutlineBlankTwoTone";
import CheckBoxRoundedIcon from "@mui/icons-material/CheckBoxRounded";
import arrowLeft from "../../../assets/icons/arrow-left.png";
import arrowLeftGreen from "../../../assets/icons/arrow-left-green.png";

import { Link } from "react-router-dom";
import arrow from "../../../assets/icons/dropdown.png";
import onInput from "../../../util/onInput";
import { connect } from "react-redux";
import { user } from "../../../redux/actions";
import _ from "lodash";

interface LoginFields {
  username?: string;
  password?: string;
}

function Login({ login, theme, ...props }: any) {
  const [loginFields, setSignUpFiels] = useState<LoginFields | undefined>(
    undefined
  );
  const onChange = (name: string, value: string) => {
    setSignUpFiels({ ...loginFields, [name]: value });
  };
  // const usernameInput = useRef<any>();
  // const passwordInput = useRef<any>();

  useEffect(() => {}, []);
  return (
    <div
      className={_.join(
        [
          "login d-flex flex-column align-items-center justify-content-center",
          theme === "light" ? "login-light bg-white" : "login-dark bg-black",
        ],
        " "
      )}
    >
      <Navbar />
      <section className="d-flex flex-column">
        <div className="login__back d-flex justify-content-end">
          <Link to="/" className="d-flex align-items-center">
            <div className="desktop align-items-center">
              بازگشت به صفحه قبل
              <img src={arrow} alt="" />
            </div>
            {theme === "dark" ? (
              <img className="mobile" src={arrowLeft} alt="" />
            ) : (
              <img className="mobile" src={arrowLeftGreen} alt="" />
            )}
          </Link>
        </div>
        <b>
          سلام
          <br />
          خوش برگشتی!
        </b>
        <Input
          name="username"
          label="نام کاربری"
          align="left"
          onInput={onInput.englishAndNumberWithoutSpace}
          onChange={onChange}
          // ref={usernameInput}
        />
        <Input
          name="password"
          label="رمز عبور"
          align="left"
          onInput={onInput.englishAndNumberWithoutSpace}
          onChange={onChange}
          // ref={passwordInput}
        />
        <div className="login__options d-flex justify-content-between align-items-center">
          <div className="d-flex align-items-center">
            <CustomCheckbox
              icon={
                <CheckBoxOutlineBlankTwoToneIcon
                  style={{
                    color: theme === "dark" ? "#666" : "#81c342",
                    fontSize: 27,
                    padding: 0,
                  }}
                />
              }
              checkedIcon={
                <CheckBoxRoundedIcon
                  style={{
                    color: theme === "dark" ? "#84de56" : "#81c342",
                    fontSize: 27,
                    padding: 0,
                  }}
                />
              }
            />
            مرا به خاطر بسپار
          </div>
          <Link to="/forget">رمز عبور خود را فراموش کرده‌اید؟</Link>
        </div>
        <button type="submit" onClick={() => login(loginFields)}>
          ورود
        </button>
        <p className="login__info" onClick={() => props.setPage("signup")}>
          <Link to="/sign-up">ساخت حساب کاربری</Link>
        </p>
      </section>
      <Footer />
    </div>
  );
}

export default connect(() => ({}), { login: user.login })(Login);
