import React, { useState, useRef, useEffect } from "react";
import { useHistory } from "react-router-dom";
import Navbar from "../../../components/Navbar";
import Footer from "../../Home/Footer";
import Timer from "../../../components/Timer";
import onInput from "../../../util/onInput";
import { Link } from "react-router-dom";
import arrow from "../../../assets/icons/dropdown.png";
import arrowLeft from "../../../assets/icons/arrow-left.png";
import arrowLeftGreen from "../../../assets/icons/arrow-left-green.png";

import { connect } from "react-redux";
import { user } from "../../../redux/actions";
import _ from "lodash";

interface SignUpFields {
  cellphone?: String;
  otp?: String;
}

function SignUp({ sendOtp, sendPhoneNumber, loginFlag, theme }: any) {
  const [level, setLevel] = useState("phonenumber");
  const [signUpFields, setSignUpFiels] = useState<SignUpFields | undefined>(
    undefined
  );
  const [error, setError] = useState<string | undefined>(undefined);
  const [resend, setResend] = useState(false);
  const history = useHistory();

  const onChange = (name: string, value: string) => {
    setSignUpFiels({ ...signUpFields, [name]: value });
  };

  const checkPhoneNumber = () => {
    if (
      signUpFields?.cellphone?.slice(0, 2) === "09" &&
      signUpFields?.cellphone.length === 11
    ) {
      setLevel("otp");
      setResend(false);
      sendPhoneNumber({ cellphone: signUpFields?.cellphone });
      setError(undefined);
    } else {
      setError("شماره موبایل خود را چک کنید.");
    }
  };

  const checkOtp = () => {
    if (signUpFields?.otp?.length === 4) {
      sendOtp({
        cellphone: signUpFields?.cellphone,
        otp: signUpFields?.otp,
        userToken: "2",
        applicationToken: "22",
      });
      setError(undefined);
    } else {
      setError("کد وارد شده را چک کنید.");
    }
  };

  const otpInput = useRef<any | undefined>(undefined);
  const numberInput = useRef<any | undefined>(undefined);

  useEffect(() => {
    numberInput.current.focus();
  }, []);

  useEffect(() => {
    if (signUpFields?.otp?.length === 4) {
      sendOtp({
        cellphone: signUpFields?.cellphone,
        otp: signUpFields?.otp,
        userToken: "2",
        applicationToken: "22",
      });
    }
  }, [signUpFields]);

  useEffect(() => {
    if (level === "phonenumber") {
      numberInput.current.focus();
    } else {
      otpInput.current.focus();
    }
  }, [level]);

  useEffect(() => {
    if (loginFlag) {
      history.push("/");
    }
  }, [loginFlag]);
  const light = theme === "light";
  return (
    <div
      className={_.join(
        [
          "signup d-flex flex-column align-items-center justify-content-center",
          light ? "signup-light bg-white" : "signup-dark bg-black",
        ],
        " "
      )}
    >
      <Navbar />
      {level === "phonenumber" && (
        <section className="d-flex flex-column">
          <b>
            ثبت نام
            <br />
            لطفا شماره موبایل خود را وارد کنید.
          </b>
          <input
            type="text"
            name="cellphone"
            inputMode="numeric"
            placeholder="09123456789"
            maxLength={11}
            onChange={(e) => onChange(e.target.name, e.target.value)}
            onInput={({ target }) =>
              ((target as HTMLInputElement).value = onInput.phonenumber(
                (target as HTMLInputElement).value
              ))
            }
            ref={numberInput}
          />
          <span className="signup__error">{error}</span>
          <button type="submit" onClick={() => checkPhoneNumber()}>
            {" "}
            ادامه
          </button>
          <p className="signup__info">
            با ثبت نام در سرویس ویدئویی دانوین قوانین
            <Link to="/"> شرایط استفاده و حریم خصوصی </Link>
            استفاده از سرویس های ما را می‌پذیرید
          </p>
        </section>
      )}
      {level === "otp" && (
        <section className="d-flex flex-column">
          <div
            className="signup__back d-flex justify-content-end"
            onClick={() => setLevel("phonenumber")}
          >
            <Link to="/sign-up" className="d-flex align-items-center">
              <div className="desktop align-items-center">
                بازگشت به صفحه قبل
                <img src={arrow} />
              </div>
              {light ? (
                <img className="mobile" src={arrowLeftGreen} alt="" />
              ) : (
                <img className="mobile" src={arrowLeft} alt="" />
              )}
            </Link>
          </div>
          <b>
            تاییدیه شماره موبایل
            <br />
            <p>کد ارسال شده به شماره {signUpFields?.cellphone} را وارد کنید.</p>
          </b>
          <input
            type="text"
            inputMode="numeric"
            name="otp"
            onChange={(e) => onChange(e.target.name, e.target.value)}
            onInput={({ target }) =>
              ((target as HTMLInputElement).value = onInput.numberOnly(
                (target as HTMLInputElement).value
              ))
            }
            placeholder={"--  --  --  --"}
            ref={otpInput}
          />
          <span className="signup__error">{error}</span>
          <button type="submit" onClick={() => checkOtp()}>
            ادامه
          </button>
          {!resend ? (
            <p className="signup__info d-flex justify-content-center">
              ارسال مجدد کد در <Timer seconds={60} refresh={setResend} /> دیگر
            </p>
          ) : (
            <p
              className="signup__info d-flex justify-content-center"
              onClick={() => checkPhoneNumber()}
            >
              دوباره ارسال کنید
            </p>
          )}
        </section>
      )}
      <Footer />
    </div>
  );
}

export default connect(
  (state: any) => ({
    loginFlag: state.user.setLogin,
  }),
  {
    sendOtp: user.otp_login,
    sendPhoneNumber: user.otp,
  }
)(SignUp);
