import React, { useState } from "react";
import { Link } from "react-router-dom";
import whiteDropdown from "../../../assets/icons/white-dropdown.png";
import greenPlay from "../../../assets/icons/play-green.png";
import greenDocument from "../../../assets/icons/document-green.png";
import whitePlay from "../../../assets/icons/white-play.png";
import document from "../../../assets/icons/document.png";
import lock from "../../../assets/icons/lock.png";
import { connect } from "react-redux";
import { book, publicApi } from "../../../redux/actions";
import location from "../../../util/location";
import _ from "lodash";

function Lesson({
  toggle,
  lesson,
  activeCategory,
  realCategories,
  vodDuration,
  theme,
}: any) {
  const [selectedLesson, setSelectedLesson] = useState(null);
  const duration = (value: number) => {
    const minute = value % 60;
    const hour = Math.round(value / 60);
    return (
      (hour > 0
        ? (hour.toString().length === 1 ? "0" + hour.toString() : hour) + ""
        : "") +
      ":" +
      (minute.toString().length === 1 ? "0" + minute.toString() : minute)
    );
  };
  const setCategory = (catId: any, videoId: any) => {
    localStorage.removeItem("bookId");
    localStorage.setItem(
      "category",
      location.getId() + "," + catId + "," + videoId
    );
  };

  const light = theme === "light";
  return (
    <div
      className={_.join(
        ["lesson d-flex flex-column", light ? "lesson-light" : "lesson-dark"],
        " "
      )}
    >
      <header
        className="desktop justify-content-between align-items-center"
        onClick={() => toggle(lesson[0].categoryId)}
      >
        <div className="d-flex align-items-center">
          <img src={whiteDropdown} alt="" />
          <h4>
            {
              realCategories.filter(
                (item: any) => item.id === lesson[0].categoryId
              )[0].name
            }
          </h4>
        </div>
        <div className="lesson__duration d-flex">
          {/* {duration(vodDuration)} */}
        </div>
      </header>
      <header
        className={
          "mobile justify-content-between align-items-center" +
          " " +
          (!lesson.active && "lesson__active")
        }
        onClick={() => toggle(lesson[0].categoryId)}
      >
        <div className="d-flex flex-column">
          <h4>
            {
              realCategories.filter(
                (item: any) => item.id === lesson[0].categoryId
              )[0].name
            }
          </h4>
          {/* <span> مدت زمان درس {lesson.duration}</span> */}
        </div>
        <div className="lesson__duration d-flex">
          <img src={whiteDropdown} alt="" />
        </div>
      </header>
      <ul
        className={
          "lesson__files d-flex flex-column justify-content-around" +
          " " +
          (lesson[0].categoryId === activeCategory && "lesson__files--active")
        }
        style={{
          height:
            lesson[0].categoryId === activeCategory
              ? lesson.length *
                (window.innerWidth > 1007
                  ? window.innerWidth / 33 + 20
                  : window.innerWidth / 33 + 45)
              : "0px",
        }}
      >
        {lesson?.map((data: any, i: any) => (
          <div className="d-flex flex-column">
            <li
              className="lesson__files--sample justify-content-between align-items-center"
              style={{
                display:
                  lesson[0].categoryId === activeCategory ? "flex" : "none",
              }}
              onClick={() =>
                setSelectedLesson(selectedLesson === data.id ? null : data.id)
              }
            >
              <div className="d-flex align-items-center">
                <Link to={"/video/" + data.id}>
                  {data.type === "video" &&
                    (light ? (
                      <img src={greenPlay} alt="" />
                    ) : (
                      <img src={whitePlay} alt="" />
                    ))}
                  {data.type === "pdf" &&
                    (light ? (
                      <img src={greenDocument} alt="" />
                    ) : (
                      <img src={document} alt="" />
                    ))}
                </Link>
                <Link to={"/video/" + data.id}>
                  <img
                    className={
                      selectedLesson === data.id
                        ? "lesson__files--sample___active"
                        : ""
                    }
                    src={`https://dnvn.ir/api/v1/file/${data.posterId}`}
                    alt=""
                  />
                </Link>
                <h5>{data.name}</h5>
              </div>
              <ul className="d-flex">
                <li>{data.type !== "pdf" && duration(data.duration)}</li>
                <Link
                  to={"/video/" + data.id}
                  onClick={() => setCategory(lesson[0].categoryId, data.name)}
                >
                  <li>مشاهده</li>
                </Link>
                <li>{data.isFreeVOD ? "دانلود" : <img src={lock} alt="" />}</li>
              </ul>
            </li>
            {selectedLesson === data.id && (
              <p style={{ fontSize: 11, padding: "10px 60px 10px 20px" }}>
                توضیحات مرتبط با این درس
              </p>
            )}
          </div>
        ))}
      </ul>
    </div>
  );
}

export default connect(
  (state: any) => ({
    activeCategory: state.publicApi.activeCategory,
    realCategories: state.publicApi.bookInfo?.categories,
    vodDuration: state.publicApi.bookInfo?.vodDuration,
  }),
  {
    toggle: publicApi.activeCategory,
  }
)(Lesson);
