import React, { useState } from "react";
import Carousel from "react-elastic-carousel";
import Course from "./Course/index";
import { Link } from "react-router-dom";
import ExpandMoreRoundedIcon from "@mui/icons-material/ExpandMoreRounded";
import { connect } from "react-redux";
import _ from "lodash";
import BookToggle from "../../../components/BookToggle";
import scroll from "../../../util/scroll";
import { transform } from "@babel/core";

function Courses({ number, courses, selectedSort, theme }: any) {
  const [activeBook, setActiveBook] = useState(null);
  const slideNumberHandler = () => {
    if (window.innerWidth >= 1440) {
      return 5;
    } else if (window.innerWidth >= 1008 && window.innerWidth < 1440) {
      return 4;
    } else if (window.innerWidth > 640 && window.innerWidth < 1008) {
      return 3;
    } else {
      return 2;
    }
  };
  const light = theme === "light";
  return (
    <section
      className={_.join(
        [
          "home-courses d-flex flex-column",
          light ? "home-courses-light" : "home-courses-dark",
        ],
        " "
      )}
      style={{
        transform:
          window.innerWidth > 1027
            ? `translateY(-${window.innerHeight / 1.9}px)`
            : "",
        padding: `calc(${window.innerHeight / 3}px) 10px 30px`,
      }}
    >
      <header className="d-flex justify-content-between align-items-center">
        <div className="d-flex flex-column">
          <h1>{selectedSort}</h1>
          {/* <span>در این قسمت شاید یک متن جهت زیباسازی قرار بگیرد.</span> */}
        </div>
        <Link to="/">بیشتر</Link>
      </header>
      <div className="desktop flex-column" onClick={() => scroll.bookScroll(1)}>
        <div className="position-relative">
          <Carousel
            itemsToShow={slideNumberHandler()}
            isRTL={true}
            enableTilt={false}
            showArrows={true}
            pagination={false}
          >
            {courses?.map((item: Object, i: any) => (
              <Course data={item} key={i} setActiveBook={setActiveBook} />
            ))}
          </Carousel>
        </div>
        {activeBook && <BookToggle book={activeBook} />}
      </div>
      <div className="home-courses__list mobile">
        {courses?.map((item: Object, i: any) => (
          <Course data={item} key={i} />
        ))}
      </div>

      <Link
        className="home-courses__more align-items-center hidden"
        to="/courses"
      >
        مشاهده بیشتر{" "}
        <ExpandMoreRoundedIcon style={{ fontSize: 25, color: "$green" }} />
      </Link>
    </section>
  );
}

export default connect((state: any) => ({
  selectedSort: state.book.selectedSort,
}))(Courses);
