import React, { useState, useEffect } from "react";
import Navbar from "../../components/Navbar";
import Courses from "./Courses";
import GradeFilter from "../../components/GradeFilter";
import Books from "./Books";
import Blogs from "./Blogs";
import Footer from "./Footer";
import Header from "./Header";
import AppDownload from "./AppDownload";
import Vocal from "../../components/Vocal/Vocal";
import scroll from "../../util/scroll";
import Loader from "../../components/Loader";
import { connect } from "react-redux";
import { book, publicApi } from "../../redux/actions";
import _ from "lodash";

function Home({
  courseList,
  getCourseList,
  grades,
  headerData,
  blogs,
  gradeFilterBooks,
  getHeader,
  bookLoading,
  publicLoading,
  theme,
}: any) {
  const [grade, setGrade] = useState(null);
  const [gradeDropdown, setGradeDropdown] = useState(false);

  useEffect(() => {
    localStorage.removeItem('bookToggle1');
    getCourseList();
    scroll.goToTop();
    getHeader({ device: 1 });
  }, []);
  return (
    <>
      <div
        className={_.join(
          [
            "home main d-flex flex-column",
            theme === "dark" ? "home-dark bg-black" : "home-light bg-white",
          ],
          " "
        )}
        style={{
          filter:  bookLoading || publicLoading ? "blur(8px)" : "",
        }}
        onClick={() => setGradeDropdown(false)}
      >
        <Navbar />
        <div className="desktop">
          <Header headerData={headerData} theme={theme} />
        </div>
        <Courses
          courses={courseList}
          theme={theme}
        />
        <GradeFilter
          grades={grades}
          grade={grade}
          setGrade={setGrade}
          gradeDropdown={gradeDropdown}
          setGradeDropdown={setGradeDropdown}
          theme={theme}
        />
        <Books
          list={gradeFilterBooks ? gradeFilterBooks : courseList}
          theme={theme}
        />
        <Blogs theme={theme} />
        <AppDownload theme={theme} />
        <Footer />
      </div>

      {(bookLoading || publicLoading) && (
        <div className="full-loader">
          <Loader size={50} />
        </div>
      )}
    </>
  );
}

export default connect(
  (state: any) => ({
    courseList: state.book.list,
    gradeFilterBooks: state.book.gradeFilterBooks,
    headerData: state.publicApi.header,
    bookLoading: state.book.loading,
    publicLoading: state.publicApi.loading,
    theme: state.publicApi.theme,
  }),
  {
    getCourseList: book.list,
    getHeader: publicApi.getHeader,
  }
)(Home);
Home.defaultProps = {
  grades: [
    {
      name: "اول",
      value: 1,
    },
    {
      name: "دوم",
      value: 2,
    },
    {
      name: "سوم",
      value: 3,
    },
    {
      name: "چهارم",
      value: 4,
    },
    {
      name: "پنجم",
      value: 5,
    },
    {
      name: "ششم",
      value: 6,
    },
    {
      name: "هفتم",
      value: 7,
    },
    {
      name: "هشتم",
      value: 8,
    },
    {
      name: "نهم",
      value: 9,
    },
    {
      name: "دهم",
      value: 10,
    },
    {
      name: "یازدهم",
      value: 11,
    },
  ],
};
